mirror of
https://github.com/tiennm99/serena.git
synced 2026-10-14 18:19:14 +00:00
0e3f665976
* Add more cpp extensions * Allow FilenameMatcher to be case insensitive --------- Co-authored-by: Darin Morrison <darinmorrison@gmail.com> Co-authored-by: silvanshade <silvanshade@users.noreply.github.com> Co-authored-by: MischaPanch
11 lines
214 B
Plaintext
11 lines
214 B
Plaintext
// -*- mode: C -*-
|
|
|
|
#include <hip/hip_runtime.h>
|
|
|
|
__global__
|
|
void add_vectors(const float* A, const float* B, float* C)
|
|
{
|
|
auto const idx = blockIdx.x * blockDim.x + threadIdx.x;
|
|
C[idx] = A[idx] + B[idx];
|
|
}
|